@@ -6,6 +6,8 @@ class ConfigDict(TypedDict):
     api_key: str
     env: str
     bypass: Optional[bool]
+    is_logging: Optional[bool]
+    timeout:Optional[int]
 
 
 class PromptStudio(PromptManager):
@@ -23,5 +25,7 @@ class PromptStudio(PromptManager):
                 - 'api_key': API key
                 - 'env': Environment ('test' or 'prod')
                 - 'bypass': Optional boolean to bypass PromptStudio server
+                - 'is_logging': Optional boolean to enable logging
+                - 'timeout': Optional int 
         """
         super().__init__(config)
